﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.UltraChart.Core.Layers;
using Infragistics.UltraChart.Core.Primitives;

namespace UltraChartBoxChart
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();


            ultraChart1.ChartType = ChartType.Composite;
            ChartArea area = new ChartArea();
            ultraChart1.CompositeChart.ChartAreas.Add(area);


            DataTable boxData = GetBoxTable();
            DataTable lineData = GetLineTable();

            BoxSetSeries boxSeries = new BoxSetSeries();
            boxSeries.Data.DataSource = boxData;
            boxSeries.Data.LabelColumn = "Name";
            boxSeries.Data.MinColumn = "Min";
            boxSeries.Data.MaxColumn = "Max";
            boxSeries.Data.Q1Column = "Q1";
            boxSeries.Data.Q2Column = "Q2";
            boxSeries.Data.Q3Column = "Q3";


            XYSeries lineSeries = new XYSeries();
            lineSeries.DataBind(lineData, "XValue", "Value", "Name");
            ultraChart1.CompositeChart.Series.Add(lineSeries);


            AxisItem xAxisBox = new AxisItem();
            xAxisBox.DataType = AxisDataType.String;
            xAxisBox.SetLabelAxisType = SetLabelAxisType.ContinuousData;
            xAxisBox.Extent = 70;
            xAxisBox.Labels.Visible = true;
            xAxisBox.Visible = true;
            area.Axes.Add(xAxisBox);


            AxisItem xAxisLine = new AxisItem();
            xAxisLine.DataType = AxisDataType.Numeric;
            xAxisLine.SetLabelAxisType = SetLabelAxisType.ContinuousData;
            xAxisLine.Extent = 70;
            xAxisLine.Labels.ItemFormat = AxisItemLabelFormat.DataValue;
            xAxisLine.Labels.ItemFormatString = "<DATA_VALUE:##>";
            xAxisLine.Margin.Near.MarginType = LocationType.RowColumn;
            xAxisLine.Margin.Near.Value = 0.45;
            xAxisLine.Visible = true ;
            xAxisLine.TickmarkStyle = AxisTickStyle.Percentage;
            xAxisLine.TickmarkPercentage = 20;
            area.Axes.Add(xAxisLine);

            AxisItem yAxis = new AxisItem();
            yAxis.DataType = AxisDataType.Numeric;
            yAxis.Labels.ItemFormat = AxisItemLabelFormat.DataValue;
            yAxis.Labels.ItemFormatString = "<DATA_VALUE:##>";
            yAxis.Extent = 30;
            yAxis.Visible = true;
            yAxis.OrientationType = AxisNumber.Y_Axis;
            yAxis.Labels.Visible = true;
            yAxis.LineColor = Color.Cyan;
            area.Axes.Add(yAxis);

            BoxChartAppearance boxchartApp = new BoxChartAppearance();
            boxchartApp.BoxWidthFactor = 0.9;
            


            ChartLayerAppearance boxLayer = new ChartLayerAppearance();
            boxLayer.ChartType = ChartType.BoxChart;
            boxLayer.ChartTypeAppearance = boxchartApp;
            boxLayer.ChartArea = area;
            boxLayer.AxisX = xAxisBox;
            boxLayer.AxisY = yAxis;
            ultraChart1.CompositeChart.ChartLayers.Add(boxLayer);



            ChartLayerAppearance lineLayer = new ChartLayerAppearance();
            lineLayer.ChartType = ChartType.ScatterChart;
            lineLayer.ChartArea = area;
            lineLayer.AxisX = xAxisLine;
            lineLayer.AxisY = yAxis;
            ultraChart1.CompositeChart.ChartLayers.Add(lineLayer);

            boxLayer.Series.Add(boxSeries);
            lineLayer.Series.Add(lineSeries);

            ultraChart1.CompositeChart.Series.Add(boxSeries);
            ultraChart1.CompositeChart.Series.Add(lineSeries);


            ScatterChartAppearance la = new ScatterChartAppearance(ultraChart1);
            la.Icon = SymbolIcon.Circle;
            la.IconSize = SymbolIconSize.Large;

            lineLayer.ChartTypeAppearance = la;


            Color[] initColor = new Color[] { Color.Red};//, Color.Gold};
            this.ultraChart1.ColorModel.ModelStyle = Infragistics.UltraChart.Shared.Styles.ColorModels.CustomLinear;
            this.ultraChart1.ColorModel.CustomPalette = initColor;


        }

        public DataTable GetBoxTable()
        {
            DataTable chartData = new DataTable();
            chartData.Columns.Add("Name", typeof(string));
            chartData.Columns.Add("Min", typeof(double));
            chartData.Columns.Add("Max", typeof(double));
            chartData.Columns.Add("Q1", typeof(double));
            chartData.Columns.Add("Q2", typeof(double));
            chartData.Columns.Add("Q3", typeof(double));

            chartData.Rows.Add(new object[] { "G12", 35, 45, 35.71561212, 39.43594323, 44.40108508 });
            chartData.Rows.Add("G13", 39, 52, 40.58681685, 45.13052085, 51.05347587);
            chartData.Rows.Add("G14", 45, 60, 46.1223987, 51.64739944, 58.70256085);
            chartData.Rows.Add("G15", 50, 69, 52.41297118, 59.10531982, 67.49766967);
            chartData.Rows.Add("G16", 58, 78, 59.56150645, 67.6401691, 77.61050533);
            chartData.Rows.Add("G17", 65, 95, 67.68502093, 77.40745654, 89.23849618);
            //chartData.Rows.Add("G18", 75, 105, 76.91649071, 88.58514709, 102.6086503);
            //chartData.Rows.Add("G19", 85, 120, 87.40702836, 101.3769039, 117.9819872);
            //chartData.Rows.Add("G20", 95, 140, 99.32835645, 116.0157993, 135.6586337);
            //chartData.Rows.Add("G21", 110, 160, 112.8756186, 132.7685614, 155.9836831);
            //chartData.Rows.Add("G22", 125, 180, 128.2705737, 151.940434, 179.3539322);
            //chartData.Rows.Add("G23", 140, 210, 145.7652263, 173.8807383, 206.2256279);
            return chartData;
        }

        private DataTable GetLineTable()
        {
            DataTable chartData = new DataTable();
            chartData.Columns.Add("Name", typeof(string));
            chartData.Columns.Add("Xvalue", typeof(double));
            chartData.Columns.Add("Value", typeof(double));

            chartData.Rows.Add("G12", 1, 33);
            chartData.Rows.Add("G12", 1, 47);

            chartData.Rows.Add("G13", 2,  37);
            chartData.Rows.Add("G13", 2, 54);
            
            chartData.Rows.Add("G14", 3, 43);
            chartData.Rows.Add("G14", 3, 62);
            
            chartData.Rows.Add("G15", 4, 48);
            chartData.Rows.Add("G15", 4, 72);
            
            chartData.Rows.Add("G16", 5, 56);
            chartData.Rows.Add("G16", 5, 80);

            chartData.Rows.Add("G17", 6, 63);
            chartData.Rows.Add("G17", 6, 98);

            //chartData.Rows.Add("G18", 7, 73);
            //chartData.Rows.Add("G18", 7, 108);
        
            //chartData.Rows.Add("G19", 8, 80);
            //chartData.Rows.Add("G19", 8, 125);
        
            //chartData.Rows.Add("G20", 9, 93);
            //chartData.Rows.Add("G20", 9, 145);
            
            //chartData.Rows.Add("G21", 10, 108);
            //chartData.Rows.Add("G21", 10, 165);
           
            //chartData.Rows.Add("G22", 11, 123);
            //chartData.Rows.Add("G22", 11, 185);
           
            //chartData.Rows.Add("G23", 12, 135);
            //chartData.Rows.Add("G23", 12, 215);
           

            return chartData;
        }

        private void ultraChart1_FillSceneGraph(object sender, Infragistics.UltraChart.Shared.Events.FillSceneGraphEventArgs e)
        {
            
            List<Primitive> list = new List<Primitive>();

            foreach (Primitive pr in e.SceneGraph)
            {

                if (pr.GetType() == typeof(Box) && pr.Column != -1)
                {
                    Box nBox = new Box(new Rectangle(((Box)pr).rect.X, ((Box)pr).rect.Y, ((Box)pr).rect.Width, ((Box)pr).rect.Height / 2));
                    nBox.PE.Fill = Color.Green;
                    list.Add(nBox);

                    Line nLine = new Line(new Point(((Box)pr).rect.X, ((Box)pr).rect.Y), new Point(((Box)pr).rect.X + ((Box)pr).rect.Width, ((Box)pr).rect.Y));
                    nLine.p1.Offset(2, 30);
                    nLine.p2.Offset(2, 30);
                    nLine.PE.StrokeWidth = 3;
                    nLine.lineStyle = new LineStyle(LineCapStyle.Triangle, LineCapStyle.Triangle, LineDrawStyle.Dash);
                    list.Add(nLine);
                }


                if (pr.GetType() == typeof(PointSet))
                {
                    DataPoint[] dpList = new DataPoint[((PointSet)pr).points.Count()];
                    ((PointSet)pr).icon = SymbolIcon.Circle;
                    ((PointSet)pr).iconSize = SymbolIconSize.Large;
                    ((PointSet)pr).PE.Fill = Color.Red;

                    int i=0;

                    foreach (DataPoint dp in ((PointSet)pr).points)
                    {
                        
                        dpList[i] = dp;
                        i++;
                    }
                    PointSet sss = new PointSet(dpList, SymbolIcon.Circle, SymbolIconSize.Medium);
                    sss.PE.Fill = Color.WhiteSmoke;
                    list.Add(sss);
                }

            }

            foreach (Primitive prrr in list) e.SceneGraph.Add(prrr);


        }
    }
}
